@@ -1,9 +1,13 @@
 package App::Netdisco::DB::ResultSet::DevicePort;
-use base 'DBIx::Class::ResultSet';
+use base 'App::Netdisco::DB::ResultSet';
 
 use strict;
 use warnings FATAL => 'all';
 
+__PACKAGE__->load_components(qw/
+  +App::Netdisco::DB::ExplicitLocking
+/);
+
 =head1 ADDITIONAL METHODS
 
 =head2 with_times
@@ -61,7 +65,7 @@ sub with_is_free {
       {
         '+columns' => { is_free =>
           \["up != 'up' and "
-              ."age(to_timestamp(extract(epoch from device.last_discover) "
+              ."age(now(), to_timestamp(extract(epoch from device.last_discover) "
                 ."- (device.uptime - lastchange)/100)) "
               ."> ?::interval",
             [{} => $interval]] },
@@ -92,7 +96,7 @@ sub only_free_ports {
         'up' => { '!=' => 'up' },
       },{
         where =>
-          \["age(to_timestamp(extract(epoch from device.last_discover) "
+          \["age(now(), to_timestamp(extract(epoch from device.last_discover) "
                 ."- (device.uptime - lastchange)/100)) "
               ."> ?::interval",
             [{} => $interval]],
@@ -133,4 +137,39 @@ sub with_vlan_count {
       });
 }
 
+=head1 SPECIAL METHODS
+
+=head2 delete( \%options? )
+
+Overrides the built-in L<DBIx::Class> delete method to more efficiently
+handle the removal or archiving of nodes.
+
+=cut
+
+sub delete {
+  my $self = shift;
+
+  my $schema = $self->result_source->schema;
+  my $ports = $self->search(undef, { columns => 'ip' });
+
+  foreach my $set (qw/
+    DevicePortPower
+    DevicePortVlan
+    DevicePortWireless
+    DevicePortSsid
+    DevicePortLog
+  /) {
+      $schema->resultset($set)->search(
+        { ip => { '-in' => $ports->as_query }},
+      )->delete;
+  }
+
+  $schema->resultset('Node')->search(
+    { switch => { '-in' => $ports->as_query }},
+  )->delete(@_);
+
+  # now let DBIC do its thing
+  return $self->next::method();
+}
+
 1;
